//******************************************************************************
//
//     PULSADOR DE BICOS INJETORES
//
//     COM PIC 12F675
//
//     OBJETIVO:  REALIZAR TESTES COM BICOS INJETORES DE VEICULOS  E
//     COLABORAR COM PROCESSO DE LIMPEZA COM CUBA ULTRASONICA (BATER BICOS NA
//     CUBA).
//
//     AUTOR: CLAUDIO LARIOS             DATA:03/03/2014
//
//     MEDIANTE 2 POTENCIOMETROS REGULAMOS O TEMPO DE INJEO E A RPM SIMULADA
//
//     PARA FINS DIDTICOS APENAS.
//
//==============================================================================
//Descomente o abaixo SOMENTE se perdeu o byte de calibrao

//    #define PERDI_BYTE_CALIBRACAO   // PROVIDENCIA BYTE PROVISRIO PARA TESTE
//==============================================================================


#include <12F675.h>
#device adc=8
#use delay(clock=4000000)
#fuses NOWDT,INTRC_IO, NOCPD, NOPROTECT, NOMCLR, PUT, BROWNOUT
#use fast_io(A)  //  sentido das portas feita pelo programador
#ifdef  PERDI_BYTE_CALIBRACAO  // calibrao do oscilador interno do pic
#ROM  0X3FF = {0X34fc}//mxima freq= 0x34fc ;mdia=0x3480; minima=0x3400
#endif
#ZERO_RAM

//==============================================================================
//   REGISTRADORES
//==============================================================================
#byte gpio   = 0x05
#byte tmr0   = 0x01
#byte tris   = 0x85
#byte t1con   =0x10
#byte tmr1h   =0x0f
#byte tmr1l   =0x0e
#byte pir1    =0x0c
#byte tmr1h   =0x0f
#byte tmr1l   =0x0e
#byte intcon  =0x8b
#byte status  =0x03

#bit  per_int =0x0b.6 //interrupo de perifricos
#bit  tmr0if  =0x0b.2 //flag over tmr0
#bit  tmr1if  =0x0c.0 //flag over tmr1
#bit  tmr0_int=0xb.5  // interrupo tmr0
#bit  tmr1_int=0x8c.0 // interrupo tmr1
#bit  ont1    =0x10.0 //liga tmr1


//==============================================================================
//   DEFINIO DE PINOS E SAIDAS
//==============================================================================

#bit  bico   = 0x5.5 //pino 2
//==============================================================================
//    VARIAVIS GLOBAIS
//==============================================================================

int   valor_periodo, valor_rpm;



//==============================================================================
//               ROTINA DE INTERRUPO DO TIMER 0
//==============================================================================


#int_timer0
void int_tmr0() {   //periodo da injeo

   bico=0; //desliga bico
   disable_interrupts(int_timer0);//desliga interrupo do tmr0
}


//==============================================================================
//               ROTINA DE INTERRUPO DO TIMER 1
//==============================================================================


#int_timer1
void int_tmr1() {  //rpm
   bico=1;  //comea a injetar os bicos
   set_timer1(valor_rpm*256);   
   set_timer0(~valor_periodo);
   tmr0if=0; //apaga flag over tmr0
   enable_interrupts(int_timer0); // liga interrupo do timer 0


}

//==============================================================================
//               ROTINA MAIN
//==============================================================================
Void Main (){
      tris=0b011111; //direo das portas
      gpio=0;//desliga ports
      setup_comparator(NC_NC_NC_NC);// desliga comparadores analgicos
      setup_adc(ADC_CLOCK_DIV_8 );// ajusta o clock do adc
      setup_counters(RTCC_INTERNAL,RTCC_DIV_4);  //TIMER 0 /16
      setup_counters(T1_INTERNAL,T1_DIV_BY_1);

      set_timer0(0); //zera tmr0
      tmr0if=0 ; //apaga flag over flow
     // enable_interrupts(INT_TIMER0); //habilita interrupo do tmr0
      set_timer1(0xff00); //ajusta tmr1=0xff00
      enable_interrupts(INT_TIMER1); //habilita interrupo do tmr0
      ont1=1; //liga timer 1
      enable_interrupts(global); //liga geral das interrupes
//==============================================================================
//       loop principal

   While (true) {

    setup_adc_ports(sAN2 | VSS_VDD);  //seleciona AN2 e 5v como referncia
    set_adc_channel(2); //ajusta para o pino 5 (AN2)
    delay_us(10); //delay
    valor_periodo = READ_ADC();// l valor da tenso de entrada do pino 5
    setup_adc_ports(sAN3 | VSS_VDD);  //seleciona AN3 e 5v como referncia
    set_adc_channel(3); //ajusta para o pino 3 (AN3)
    delay_us(10); //delay
    valor_rpm = READ_ADC();// l valor da tenso de entrada do pino 3 pot rpm
    delay_ms(100);


   }//WHILE
}//MAIN
